# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vpc.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import networktypes_pb2 as networktypes__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tvpc.proto\x12\x1eopi_api.network.cloud.v1alpha1\x1a\x12networktypes.proto\x1a\x19google/api/resource.proto\"\xce\x01\n\x03Vpc\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12;\n\x04spec\x18\x02 \x01(\x0b\x32\'.opi_api.network.cloud.v1alpha1.VpcSpecR\x04spec\x12\x41\n\x06status\x18\x03 \x01(\x0b\x32).opi_api.network.cloud.v1alpha1.VpcStatusR\x06status:3\xea\x41\x30\n\"opi_api.network.cloud.v1alpha1/vpc\x12\nvpcs/{vpc}\"\xf3\x04\n\x07VpcSpec\x12;\n\x04type\x18\x01 \x01(\x0e\x32\'.opi_api.network.cloud.v1alpha1.VPCTypeR\x04type\x12\x34\n\x17v4_route_table_name_ref\x18\x02 \x01(\tR\x13v4RouteTableNameRef\x12\x34\n\x17v6_route_table_name_ref\x18\x03 \x01(\tR\x13v6RouteTableNameRef\x12K\n#ingress_v4_security_policy_name_ref\x18\x04 \x03(\tR\x1eingressV4SecurityPolicyNameRef\x12K\n#ingress_v6_security_policy_name_ref\x18\x05 \x03(\tR\x1eingressV6SecurityPolicyNameRef\x12I\n\"egress_v4_security_policy_name_ref\x18\x06 \x03(\tR\x1d\x65gressV4SecurityPolicyNameRef\x12I\n\"egress_v6_security_policy_name_ref\x18\x07 \x03(\tR\x1d\x65gressV6SecurityPolicyNameRef\x12,\n\x12virtual_router_mac\x18\x08 \x01(\x0cR\x10virtualRouterMac\x12O\n\x0c\x66\x61\x62ric_encap\x18\t \x01(\x0b\x32,.opi_api.network.opinetcommon.v1alpha1.EncapR\x0b\x66\x61\x62ricEncap\x12\x10\n\x03tos\x18\n \x01(\x05R\x03tos\"\xcf\x01\n\tVpcStatus\x12L\n\thw_handle\x18\x01 \x01(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.HwHandleR\x08hwHandle\x12Q\n\x0c\x62\x64_hw_handle\x18\x02 \x01(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.HwHandleR\nbdHwHandle\x12!\n\x0csubnet_count\x18\x03 \x01(\x05R\x0bsubnetCount\"\xe6\x01\n\x07VPCPeer\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12?\n\x04spec\x18\x02 \x01(\x0b\x32+.opi_api.network.cloud.v1alpha1.VPCPeerSpecR\x04spec\x12\x45\n\x06status\x18\x03 \x01(\x0b\x32-.opi_api.network.cloud.v1alpha1.VPCPeerStatusR\x06status:?\xea\x41<\n&opi_api.network.cloud.v1alpha1/vpcpeer\x12\x12vpcpeers/{vpcpeer}\"U\n\x0bVPCPeerSpec\x12\"\n\rvpc1_name_ref\x18\x01 \x01(\tR\x0bvpc1NameRef\x12\"\n\rvpc2_name_ref\x18\x02 \x01(\tR\x0bvpc2NameRef\"\x0f\n\rVPCPeerStatus*e\n\x07VPCType\x12\x18\n\x14VPC_TYPE_UNSPECIFIED\x10\x00\x12\x15\n\x11VPC_TYPE_UNDERLAY\x10\x01\x12\x13\n\x0fVPC_TYPE_TENANT\x10\x02\x12\x14\n\x10VPC_TYPE_CONTROL\x10\x03\x42i\n\x1eopi_api.network.cloud.v1alpha1B\x08VpcProtoP\x01Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vpc_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036opi_api.network.cloud.v1alpha1B\010VpcProtoP\001Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/go'
  _globals['_VPC']._options = None
  _globals['_VPC']._serialized_options = b'\352A0\n\"opi_api.network.cloud.v1alpha1/vpc\022\nvpcs/{vpc}'
  _globals['_VPCPEER']._options = None
  _globals['_VPCPEER']._serialized_options = b'\352A<\n&opi_api.network.cloud.v1alpha1/vpcpeer\022\022vpcpeers/{vpcpeer}'
  _globals['_VPCTYPE']._serialized_start=1478
  _globals['_VPCTYPE']._serialized_end=1579
  _globals['_VPC']._serialized_start=93
  _globals['_VPC']._serialized_end=299
  _globals['_VPCSPEC']._serialized_start=302
  _globals['_VPCSPEC']._serialized_end=929
  _globals['_VPCSTATUS']._serialized_start=932
  _globals['_VPCSTATUS']._serialized_end=1139
  _globals['_VPCPEER']._serialized_start=1142
  _globals['_VPCPEER']._serialized_end=1372
  _globals['_VPCPEERSPEC']._serialized_start=1374
  _globals['_VPCPEERSPEC']._serialized_end=1459
  _globals['_VPCPEERSTATUS']._serialized_start=1461
  _globals['_VPCPEERSTATUS']._serialized_end=1476
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import backend_malloc_pb2 as backend__malloc__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class MallocVolumeServiceStub(object):
    """Back End Malloc Volume APIs. This is debug interface for malloc block devices.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateMallocVolume = channel.unary_unary(
                '/opi_api.storage.v1.MallocVolumeService/CreateMallocVolume',
                request_serializer=backend__malloc__pb2.CreateMallocVolumeRequest.SerializeToString,
                response_deserializer=backend__malloc__pb2.MallocVolume.FromString,
                )
        self.DeleteMallocVolume = channel.unary_unary(
                '/opi_api.storage.v1.MallocVolumeService/DeleteMallocVolume',
                request_serializer=backend__malloc__pb2.DeleteMallocVolumeRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateMallocVolume = channel.unary_unary(
                '/opi_api.storage.v1.MallocVolumeService/UpdateMallocVolume',
                request_serializer=backend__malloc__pb2.UpdateMallocVolumeRequest.SerializeToString,
                response_deserializer=backend__malloc__pb2.MallocVolume.FromString,
                )
        self.ListMallocVolumes = channel.unary_unary(
                '/opi_api.storage.v1.MallocVolumeService/ListMallocVolumes',
                request_serializer=backend__malloc__pb2.ListMallocVolumesRequest.SerializeToString,
                response_deserializer=backend__malloc__pb2.ListMallocVolumesResponse.FromString,
                )
        self.GetMallocVolume = channel.unary_unary(
                '/opi_api.storage.v1.MallocVolumeService/GetMallocVolume',
                request_serializer=backend__malloc__pb2.GetMallocVolumeRequest.SerializeToString,
                response_deserializer=backend__malloc__pb2.MallocVolume.FromString,
                )
        self.StatsMallocVolume = channel.unary_unary(
                '/opi_api.storage.v1.MallocVolumeService/StatsMallocVolume',
                request_serializer=backend__malloc__pb2.StatsMallocVolumeRequest.SerializeToString,
                response_deserializer=backend__malloc__pb2.StatsMallocVolumeResponse.FromString,
                )


class MallocVolumeServiceServicer(object):
    """Back End Malloc Volume APIs. This is debug interface for malloc block devices.
    """

    def CreateMallocVolume(self, request, context):
        """Create a Malloc Volume
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteMallocVolume(self, request, context):
        """Delete a Malloc Volume
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateMallocVolume(self, request, context):
        """Update a Malloc Volume
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListMallocVolumes(self, request, context):
        """List Malloc Volumes
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMallocVolume(self, request, context):
        """Get a Malloc Volume
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StatsMallocVolume(self, request, context):
        """Get a Malloc Volume statistics
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MallocVolumeServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateMallocVolume': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateMallocVolume,
                    request_deserializer=backend__malloc__pb2.CreateMallocVolumeRequest.FromString,
                    response_serializer=backend__malloc__pb2.MallocVolume.SerializeToString,
            ),
            'DeleteMallocVolume': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteMallocVolume,
                    request_deserializer=backend__malloc__pb2.DeleteMallocVolumeRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateMallocVolume': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateMallocVolume,
                    request_deserializer=backend__malloc__pb2.UpdateMallocVolumeRequest.FromString,
                    response_serializer=backend__malloc__pb2.MallocVolume.SerializeToString,
            ),
            'ListMallocVolumes': grpc.unary_unary_rpc_method_handler(
                    servicer.ListMallocVolumes,
                    request_deserializer=backend__malloc__pb2.ListMallocVolumesRequest.FromString,
                    response_serializer=backend__malloc__pb2.ListMallocVolumesResponse.SerializeToString,
            ),
            'GetMallocVolume': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMallocVolume,
                    request_deserializer=backend__malloc__pb2.GetMallocVolumeRequest.FromString,
                    response_serializer=backend__malloc__pb2.MallocVolume.SerializeToString,
            ),
            'StatsMallocVolume': grpc.unary_unary_rpc_method_handler(
                    servicer.StatsMallocVolume,
                    request_deserializer=backend__malloc__pb2.StatsMallocVolumeRequest.FromString,
                    response_serializer=backend__malloc__pb2.StatsMallocVolumeResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'opi_api.storage.v1.MallocVolumeService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MallocVolumeService(object):
    """Back End Malloc Volume APIs. This is debug interface for malloc block devices.
    """

    @staticmethod
    def CreateMallocVolume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.MallocVolumeService/CreateMallocVolume',
            backend__malloc__pb2.CreateMallocVolumeRequest.SerializeToString,
            backend__malloc__pb2.MallocVolume.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteMallocVolume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.MallocVolumeService/DeleteMallocVolume',
            backend__malloc__pb2.DeleteMallocVolumeRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateMallocVolume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.MallocVolumeService/UpdateMallocVolume',
            backend__malloc__pb2.UpdateMallocVolumeRequest.SerializeToString,
            backend__malloc__pb2.MallocVolume.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListMallocVolumes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.MallocVolumeService/ListMallocVolumes',
            backend__malloc__pb2.ListMallocVolumesRequest.SerializeToString,
            backend__malloc__pb2.ListMallocVolumesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMallocVolume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.MallocVolumeService/GetMallocVolume',
            backend__malloc__pb2.GetMallocVolumeRequest.SerializeToString,
            backend__malloc__pb2.MallocVolume.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StatsMallocVolume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.MallocVolumeService/StatsMallocVolume',
            backend__malloc__pb2.StatsMallocVolumeRequest.SerializeToString,
            backend__malloc__pb2.StatsMallocVolumeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import backend_nvme_pb2 as backend__nvme__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class NvmeRemoteControllerServiceStub(object):
    """Back End APIs. Responsible for connection to external Nvme devices
    e.g. connection to Nvme/TCP Nvme/RDMA and local Nvme/Pcie ssds
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateNvmeRemoteController = channel.unary_unary(
                '/opi_api.storage.v1.NvmeRemoteControllerService/CreateNvmeRemoteController',
                request_serializer=backend__nvme__pb2.CreateNvmeRemoteControllerRequest.SerializeToString,
                response_deserializer=backend__nvme__pb2.NvmeRemoteController.FromString,
                )
        self.DeleteNvmeRemoteController = channel.unary_unary(
                '/opi_api.storage.v1.NvmeRemoteControllerService/DeleteNvmeRemoteController',
                request_serializer=backend__nvme__pb2.DeleteNvmeRemoteControllerRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateNvmeRemoteController = channel.unary_unary(
                '/opi_api.storage.v1.NvmeRemoteControllerService/UpdateNvmeRemoteController',
                request_serializer=backend__nvme__pb2.UpdateNvmeRemoteControllerRequest.SerializeToString,
                response_deserializer=backend__nvme__pb2.NvmeRemoteController.FromString,
                )
        self.ListNvmeRemoteControllers = channel.unary_unary(
                '/opi_api.storage.v1.NvmeRemoteControllerService/ListNvmeRemoteControllers',
                request_serializer=backend__nvme__pb2.ListNvmeRemoteControllersRequest.SerializeToString,
                response_deserializer=backend__nvme__pb2.ListNvmeRemoteControllersResponse.FromString,
                )
        self.GetNvmeRemoteController = channel.unary_unary(
                '/opi_api.storage.v1.NvmeRemoteControllerService/GetNvmeRemoteController',
                request_serializer=backend__nvme__pb2.GetNvmeRemoteControllerRequest.SerializeToString,
                response_deserializer=backend__nvme__pb2.NvmeRemoteController.FromString,
                )
        self.ResetNvmeRemoteController = channel.unary_unary(
                '/opi_api.storage.v1.NvmeRemoteControllerService/ResetNvmeRemoteController',
                request_serializer=backend__nvme__pb2.ResetNvmeRemoteControllerRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.StatsNvmeRemoteController = channel.unary_unary(
                '/opi_api.storage.v1.NvmeRemoteControllerService/StatsNvmeRemoteController',
                request_serializer=backend__nvme__pb2.StatsNvmeRemoteControllerRequest.SerializeToString,
                response_deserializer=backend__nvme__pb2.StatsNvmeRemoteControllerResponse.FromString,
                )
        self.ListNvmeRemoteNamespaces = channel.unary_unary(
                '/opi_api.storage.v1.NvmeRemoteControllerService/ListNvmeRemoteNamespaces',
                request_serializer=backend__nvme__pb2.ListNvmeRemoteNamespacesRequest.SerializeToString,
                response_deserializer=backend__nvme__pb2.ListNvmeRemoteNamespacesResponse.FromString,
                )
        self.GetNvmeRemoteNamespace = channel.unary_unary(
                '/opi_api.storage.v1.NvmeRemoteControllerService/GetNvmeRemoteNamespace',
                request_serializer=backend__nvme__pb2.GetNvmeRemoteNamespaceRequest.SerializeToString,
                response_deserializer=backend__nvme__pb2.NvmeRemoteNamespace.FromString,
                )
        self.CreateNvmePath = channel.unary_unary(
                '/opi_api.storage.v1.NvmeRemoteControllerService/CreateNvmePath',
                request_serializer=backend__nvme__pb2.CreateNvmePathRequest.SerializeToString,
                response_deserializer=backend__nvme__pb2.NvmePath.FromString,
                )
        self.DeleteNvmePath = channel.unary_unary(
                '/opi_api.storage.v1.NvmeRemoteControllerService/DeleteNvmePath',
                request_serializer=backend__nvme__pb2.DeleteNvmePathRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateNvmePath = channel.unary_unary(
                '/opi_api.storage.v1.NvmeRemoteControllerService/UpdateNvmePath',
                request_serializer=backend__nvme__pb2.UpdateNvmePathRequest.SerializeToString,
                response_deserializer=backend__nvme__pb2.NvmePath.FromString,
                )
        self.ListNvmePaths = channel.unary_unary(
                '/opi_api.storage.v1.NvmeRemoteControllerService/ListNvmePaths',
                request_serializer=backend__nvme__pb2.ListNvmePathsRequest.SerializeToString,
                response_deserializer=backend__nvme__pb2.ListNvmePathsResponse.FromString,
                )
        self.GetNvmePath = channel.unary_unary(
                '/opi_api.storage.v1.NvmeRemoteControllerService/GetNvmePath',
                request_serializer=backend__nvme__pb2.GetNvmePathRequest.SerializeToString,
                response_deserializer=backend__nvme__pb2.NvmePath.FromString,
                )
        self.StatsNvmePath = channel.unary_unary(
                '/opi_api.storage.v1.NvmeRemoteControllerService/StatsNvmePath',
                request_serializer=backend__nvme__pb2.StatsNvmePathRequest.SerializeToString,
                response_deserializer=backend__nvme__pb2.StatsNvmePathResponse.FromString,
                )


class NvmeRemoteControllerServiceServicer(object):
    """Back End APIs. Responsible for connection to external Nvme devices
    e.g. connection to Nvme/TCP Nvme/RDMA and local Nvme/Pcie ssds
    """

    def CreateNvmeRemoteController(self, request, context):
        """Create an Nvme Remote Controller
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteNvmeRemoteController(self, request, context):
        """Delete an Nvme Remote Controller
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateNvmeRemoteController(self, request, context):
        """Update an Nvme Remote Controller
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListNvmeRemoteControllers(self, request, context):
        """List Nvme Remote Controllers
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNvmeRemoteController(self, request, context):
        """Get an Nvme Remote Controller
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResetNvmeRemoteController(self, request, context):
        """Reset an Nvme Remote Controller
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StatsNvmeRemoteController(self, request, context):
        """Get an Nvme Remote Controller statistics
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListNvmeRemoteNamespaces(self, request, context):
        """List Nvme Remote Namespaces
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNvmeRemoteNamespace(self, request, context):
        """Get an Nvme Remote Namespace
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateNvmePath(self, request, context):
        """Create an Nvme Path
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteNvmePath(self, request, context):
        """Delete an Nvme Path
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateNvmePath(self, request, context):
        """Update an Nvme Path
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListNvmePaths(self, request, context):
        """List Nvme Paths
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNvmePath(self, request, context):
        """Get an Nvme Path
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StatsNvmePath(self, request, context):
        """Get an Nvme Path statistics
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NvmeRemoteControllerServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateNvmeRemoteController': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNvmeRemoteController,
                    request_deserializer=backend__nvme__pb2.CreateNvmeRemoteControllerRequest.FromString,
                    response_serializer=backend__nvme__pb2.NvmeRemoteController.SerializeToString,
            ),
            'DeleteNvmeRemoteController': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteNvmeRemoteController,
                    request_deserializer=backend__nvme__pb2.DeleteNvmeRemoteControllerRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateNvmeRemoteController': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateNvmeRemoteController,
                    request_deserializer=backend__nvme__pb2.UpdateNvmeRemoteControllerRequest.FromString,
                    response_serializer=backend__nvme__pb2.NvmeRemoteController.SerializeToString,
            ),
            'ListNvmeRemoteControllers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNvmeRemoteControllers,
                    request_deserializer=backend__nvme__pb2.ListNvmeRemoteControllersRequest.FromString,
                    response_serializer=backend__nvme__pb2.ListNvmeRemoteControllersResponse.SerializeToString,
            ),
            'GetNvmeRemoteController': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNvmeRemoteController,
                    request_deserializer=backend__nvme__pb2.GetNvmeRemoteControllerRequest.FromString,
                    response_serializer=backend__nvme__pb2.NvmeRemoteController.SerializeToString,
            ),
            'ResetNvmeRemoteController': grpc.unary_unary_rpc_method_handler(
                    servicer.ResetNvmeRemoteController,
                    request_deserializer=backend__nvme__pb2.ResetNvmeRemoteControllerRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'StatsNvmeRemoteController': grpc.unary_unary_rpc_method_handler(
                    servicer.StatsNvmeRemoteController,
                    request_deserializer=backend__nvme__pb2.StatsNvmeRemoteControllerRequest.FromString,
                    response_serializer=backend__nvme__pb2.StatsNvmeRemoteControllerResponse.SerializeToString,
            ),
            'ListNvmeRemoteNamespaces': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNvmeRemoteNamespaces,
                    request_deserializer=backend__nvme__pb2.ListNvmeRemoteNamespacesRequest.FromString,
                    response_serializer=backend__nvme__pb2.ListNvmeRemoteNamespacesResponse.SerializeToString,
            ),
            'GetNvmeRemoteNamespace': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNvmeRemoteNamespace,
                    request_deserializer=backend__nvme__pb2.GetNvmeRemoteNamespaceRequest.FromString,
                    response_serializer=backend__nvme__pb2.NvmeRemoteNamespace.SerializeToString,
            ),
            'CreateNvmePath': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNvmePath,
                    request_deserializer=backend__nvme__pb2.CreateNvmePathRequest.FromString,
                    response_serializer=backend__nvme__pb2.NvmePath.SerializeToString,
            ),
            'DeleteNvmePath': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteNvmePath,
                    request_deserializer=backend__nvme__pb2.DeleteNvmePathRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateNvmePath': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateNvmePath,
                    request_deserializer=backend__nvme__pb2.UpdateNvmePathRequest.FromString,
                    response_serializer=backend__nvme__pb2.NvmePath.SerializeToString,
            ),
            'ListNvmePaths': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNvmePaths,
                    request_deserializer=backend__nvme__pb2.ListNvmePathsRequest.FromString,
                    response_serializer=backend__nvme__pb2.ListNvmePathsResponse.SerializeToString,
            ),
            'GetNvmePath': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNvmePath,
                    request_deserializer=backend__nvme__pb2.GetNvmePathRequest.FromString,
                    response_serializer=backend__nvme__pb2.NvmePath.SerializeToString,
            ),
            'StatsNvmePath': grpc.unary_unary_rpc_method_handler(
                    servicer.StatsNvmePath,
                    request_deserializer=backend__nvme__pb2.StatsNvmePathRequest.FromString,
                    response_serializer=backend__nvme__pb2.StatsNvmePathResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'opi_api.storage.v1.NvmeRemoteControllerService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class NvmeRemoteControllerService(object):
    """Back End APIs. Responsible for connection to external Nvme devices
    e.g. connection to Nvme/TCP Nvme/RDMA and local Nvme/Pcie ssds
    """

    @staticmethod
    def CreateNvmeRemoteController(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NvmeRemoteControllerService/CreateNvmeRemoteController',
            backend__nvme__pb2.CreateNvmeRemoteControllerRequest.SerializeToString,
            backend__nvme__pb2.NvmeRemoteController.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteNvmeRemoteController(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NvmeRemoteControllerService/DeleteNvmeRemoteController',
            backend__nvme__pb2.DeleteNvmeRemoteControllerRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateNvmeRemoteController(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NvmeRemoteControllerService/UpdateNvmeRemoteController',
            backend__nvme__pb2.UpdateNvmeRemoteControllerRequest.SerializeToString,
            backend__nvme__pb2.NvmeRemoteController.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListNvmeRemoteControllers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NvmeRemoteControllerService/ListNvmeRemoteControllers',
            backend__nvme__pb2.ListNvmeRemoteControllersRequest.SerializeToString,
            backend__nvme__pb2.ListNvmeRemoteControllersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNvmeRemoteController(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NvmeRemoteControllerService/GetNvmeRemoteController',
            backend__nvme__pb2.GetNvmeRemoteControllerRequest.SerializeToString,
            backend__nvme__pb2.NvmeRemoteController.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResetNvmeRemoteController(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NvmeRemoteControllerService/ResetNvmeRemoteController',
            backend__nvme__pb2.ResetNvmeRemoteControllerRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StatsNvmeRemoteController(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NvmeRemoteControllerService/StatsNvmeRemoteController',
            backend__nvme__pb2.StatsNvmeRemoteControllerRequest.SerializeToString,
            backend__nvme__pb2.StatsNvmeRemoteControllerResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListNvmeRemoteNamespaces(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NvmeRemoteControllerService/ListNvmeRemoteNamespaces',
            backend__nvme__pb2.ListNvmeRemoteNamespacesRequest.SerializeToString,
            backend__nvme__pb2.ListNvmeRemoteNamespacesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNvmeRemoteNamespace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NvmeRemoteControllerService/GetNvmeRemoteNamespace',
            backend__nvme__pb2.GetNvmeRemoteNamespaceRequest.SerializeToString,
            backend__nvme__pb2.NvmeRemoteNamespace.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateNvmePath(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NvmeRemoteControllerService/CreateNvmePath',
            backend__nvme__pb2.CreateNvmePathRequest.SerializeToString,
            backend__nvme__pb2.NvmePath.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteNvmePath(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NvmeRemoteControllerService/DeleteNvmePath',
            backend__nvme__pb2.DeleteNvmePathRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateNvmePath(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NvmeRemoteControllerService/UpdateNvmePath',
            backend__nvme__pb2.UpdateNvmePathRequest.SerializeToString,
            backend__nvme__pb2.NvmePath.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListNvmePaths(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NvmeRemoteControllerService/ListNvmePaths',
            backend__nvme__pb2.ListNvmePathsRequest.SerializeToString,
            backend__nvme__pb2.ListNvmePathsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNvmePath(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NvmeRemoteControllerService/GetNvmePath',
            backend__nvme__pb2.GetNvmePathRequest.SerializeToString,
            backend__nvme__pb2.NvmePath.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StatsNvmePath(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.NvmeRemoteControllerService/StatsNvmePath',
            backend__nvme__pb2.StatsNvmePathRequest.SerializeToString,
            backend__nvme__pb2.StatsNvmePathResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import networkinterfaces_pb2 as networkinterfaces__pb2


class NetInterfaceServiceStub(object):
    """Service functions for Network Interface exported by the server
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetNetInterface = channel.unary_unary(
                '/opi_api.network.opinetcommon.v1alpha1.NetInterfaceService/GetNetInterface',
                request_serializer=networkinterfaces__pb2.GetNetInterfaceRequest.SerializeToString,
                response_deserializer=networkinterfaces__pb2.NetInterface.FromString,
                )
        self.ListNetInterfaces = channel.unary_unary(
                '/opi_api.network.opinetcommon.v1alpha1.NetInterfaceService/ListNetInterfaces',
                request_serializer=networkinterfaces__pb2.ListNetInterfacesRequest.SerializeToString,
                response_deserializer=networkinterfaces__pb2.ListNetInterfacesResponse.FromString,
                )
        self.UpdateNetInterface = channel.unary_unary(
                '/opi_api.network.opinetcommon.v1alpha1.NetInterfaceService/UpdateNetInterface',
                request_serializer=networkinterfaces__pb2.UpdateNetInterfaceRequest.SerializeToString,
                response_deserializer=networkinterfaces__pb2.NetInterface.FromString,
                )


class NetInterfaceServiceServicer(object):
    """Service functions for Network Interface exported by the server
    """

    def GetNetInterface(self, request, context):
        """Retrieves the interface information for a given interface
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListNetInterfaces(self, request, context):
        """Retrieves the set of interfaces on the device
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateNetInterface(self, request, context):
        """A method for setting or changing configuration of an interface
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NetInterfaceServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetNetInterface': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNetInterface,
                    request_deserializer=networkinterfaces__pb2.GetNetInterfaceRequest.FromString,
                    response_serializer=networkinterfaces__pb2.NetInterface.SerializeToString,
            ),
            'ListNetInterfaces': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNetInterfaces,
                    request_deserializer=networkinterfaces__pb2.ListNetInterfacesRequest.FromString,
                    response_serializer=networkinterfaces__pb2.ListNetInterfacesResponse.SerializeToString,
            ),
            'UpdateNetInterface': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateNetInterface,
                    request_deserializer=networkinterfaces__pb2.UpdateNetInterfaceRequest.FromString,
                    response_serializer=networkinterfaces__pb2.NetInterface.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'opi_api.network.opinetcommon.v1alpha1.NetInterfaceService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class NetInterfaceService(object):
    """Service functions for Network Interface exported by the server
    """

    @staticmethod
    def GetNetInterface(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.network.opinetcommon.v1alpha1.NetInterfaceService/GetNetInterface',
            networkinterfaces__pb2.GetNetInterfaceRequest.SerializeToString,
            networkinterfaces__pb2.NetInterface.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListNetInterfaces(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.network.opinetcommon.v1alpha1.NetInterfaceService/ListNetInterfaces',
            networkinterfaces__pb2.ListNetInterfacesRequest.SerializeToString,
            networkinterfaces__pb2.ListNetInterfacesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateNetInterface(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.network.opinetcommon.v1alpha1.NetInterfaceService/UpdateNetInterface',
            networkinterfaces__pb2.UpdateNetInterfaceRequest.SerializeToString,
            networkinterfaces__pb2.NetInterface.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
import l2_xpu_infra_mgr_pb2 as l2__xpu__infra__mgr__pb2


class LogicalBridgeServiceStub(object):
    """Management of LogicalBridge Resources
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateLogicalBridge = channel.unary_unary(
                '/opi_api.network.evpn_gw.v1alpha1.LogicalBridgeService/CreateLogicalBridge',
                request_serializer=l2__xpu__infra__mgr__pb2.CreateLogicalBridgeRequest.SerializeToString,
                response_deserializer=l2__xpu__infra__mgr__pb2.LogicalBridge.FromString,
                )
        self.ListLogicalBridges = channel.unary_unary(
                '/opi_api.network.evpn_gw.v1alpha1.LogicalBridgeService/ListLogicalBridges',
                request_serializer=l2__xpu__infra__mgr__pb2.ListLogicalBridgesRequest.SerializeToString,
                response_deserializer=l2__xpu__infra__mgr__pb2.ListLogicalBridgesResponse.FromString,
                )
        self.GetLogicalBridge = channel.unary_unary(
                '/opi_api.network.evpn_gw.v1alpha1.LogicalBridgeService/GetLogicalBridge',
                request_serializer=l2__xpu__infra__mgr__pb2.GetLogicalBridgeRequest.SerializeToString,
                response_deserializer=l2__xpu__infra__mgr__pb2.LogicalBridge.FromString,
                )
        self.DeleteLogicalBridge = channel.unary_unary(
                '/opi_api.network.evpn_gw.v1alpha1.LogicalBridgeService/DeleteLogicalBridge',
                request_serializer=l2__xpu__infra__mgr__pb2.DeleteLogicalBridgeRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateLogicalBridge = channel.unary_unary(
                '/opi_api.network.evpn_gw.v1alpha1.LogicalBridgeService/UpdateLogicalBridge',
                request_serializer=l2__xpu__infra__mgr__pb2.UpdateLogicalBridgeRequest.SerializeToString,
                response_deserializer=l2__xpu__infra__mgr__pb2.LogicalBridge.FromString,
                )


class LogicalBridgeServiceServicer(object):
    """Management of LogicalBridge Resources
    """

    def CreateLogicalBridge(self, request, context):
        """Create a Logical Bridge
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListLogicalBridges(self, request, context):
        """List Logical Bridges
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLogicalBridge(self, request, context):
        """Retrieve a Logical Bridge
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteLogicalBridge(self, request, context):
        """Delete a Logical Bridge
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateLogicalBridge(self, request, context):
        """Update a Logical Bridge
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_LogicalBridgeServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateLogicalBridge': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateLogicalBridge,
                    request_deserializer=l2__xpu__infra__mgr__pb2.CreateLogicalBridgeRequest.FromString,
                    response_serializer=l2__xpu__infra__mgr__pb2.LogicalBridge.SerializeToString,
            ),
            'ListLogicalBridges': grpc.unary_unary_rpc_method_handler(
                    servicer.ListLogicalBridges,
                    request_deserializer=l2__xpu__infra__mgr__pb2.ListLogicalBridgesRequest.FromString,
                    response_serializer=l2__xpu__infra__mgr__pb2.ListLogicalBridgesResponse.SerializeToString,
            ),
            'GetLogicalBridge': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLogicalBridge,
                    request_deserializer=l2__xpu__infra__mgr__pb2.GetLogicalBridgeRequest.FromString,
                    response_serializer=l2__xpu__infra__mgr__pb2.LogicalBridge.SerializeToString,
            ),
            'DeleteLogicalBridge': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteLogicalBridge,
                    request_deserializer=l2__xpu__infra__mgr__pb2.DeleteLogicalBridgeRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateLogicalBridge': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateLogicalBridge,
                    request_deserializer=l2__xpu__infra__mgr__pb2.UpdateLogicalBridgeRequest.FromString,
                    response_serializer=l2__xpu__infra__mgr__pb2.LogicalBridge.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'opi_api.network.evpn_gw.v1alpha1.LogicalBridgeService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class LogicalBridgeService(object):
    """Management of LogicalBridge Resources
    """

    @staticmethod
    def CreateLogicalBridge(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.network.evpn_gw.v1alpha1.LogicalBridgeService/CreateLogicalBridge',
            l2__xpu__infra__mgr__pb2.CreateLogicalBridgeRequest.SerializeToString,
            l2__xpu__infra__mgr__pb2.LogicalBridge.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListLogicalBridges(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.network.evpn_gw.v1alpha1.LogicalBridgeService/ListLogicalBridges',
            l2__xpu__infra__mgr__pb2.ListLogicalBridgesRequest.SerializeToString,
            l2__xpu__infra__mgr__pb2.ListLogicalBridgesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLogicalBridge(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.network.evpn_gw.v1alpha1.LogicalBridgeService/GetLogicalBridge',
            l2__xpu__infra__mgr__pb2.GetLogicalBridgeRequest.SerializeToString,
            l2__xpu__infra__mgr__pb2.LogicalBridge.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteLogicalBridge(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.network.evpn_gw.v1alpha1.LogicalBridgeService/DeleteLogicalBridge',
            l2__xpu__infra__mgr__pb2.DeleteLogicalBridgeRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateLogicalBridge(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.network.evpn_gw.v1alpha1.LogicalBridgeService/UpdateLogicalBridge',
            l2__xpu__infra__mgr__pb2.UpdateLogicalBridgeRequest.SerializeToString,
            l2__xpu__infra__mgr__pb2.LogicalBridge.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class BridgePortServiceStub(object):
    """Management of BridgePort resources
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateBridgePort = channel.unary_unary(
                '/opi_api.network.evpn_gw.v1alpha1.BridgePortService/CreateBridgePort',
                request_serializer=l2__xpu__infra__mgr__pb2.CreateBridgePortRequest.SerializeToString,
                response_deserializer=l2__xpu__infra__mgr__pb2.BridgePort.FromString,
                )
        self.ListBridgePorts = channel.unary_unary(
                '/opi_api.network.evpn_gw.v1alpha1.BridgePortService/ListBridgePorts',
                request_serializer=l2__xpu__infra__mgr__pb2.ListBridgePortsRequest.SerializeToString,
                response_deserializer=l2__xpu__infra__mgr__pb2.ListBridgePortsResponse.FromString,
                )
        self.GetBridgePort = channel.unary_unary(
                '/opi_api.network.evpn_gw.v1alpha1.BridgePortService/GetBridgePort',
                request_serializer=l2__xpu__infra__mgr__pb2.GetBridgePortRequest.SerializeToString,
                response_deserializer=l2__xpu__infra__mgr__pb2.BridgePort.FromString,
                )
        self.DeleteBridgePort = channel.unary_unary(
                '/opi_api.network.evpn_gw.v1alpha1.BridgePortService/DeleteBridgePort',
                request_serializer=l2__xpu__infra__mgr__pb2.DeleteBridgePortRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateBridgePort = channel.unary_unary(
                '/opi_api.network.evpn_gw.v1alpha1.BridgePortService/UpdateBridgePort',
                request_serializer=l2__xpu__infra__mgr__pb2.UpdateBridgePortRequest.SerializeToString,
                response_deserializer=l2__xpu__infra__mgr__pb2.BridgePort.FromString,
                )


class BridgePortServiceServicer(object):
    """Management of BridgePort resources
    """

    def CreateBridgePort(self, request, context):
        """Create a Bridge Port
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListBridgePorts(self, request, context):
        """List Bridge Ports
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBridgePort(self, request, context):
        """Retrieve a Bridge Port
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteBridgePort(self, request, context):
        """Delete a Bridge Port
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateBridgePort(self, request, context):
        """Update a Bridge Port
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BridgePortServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateBridgePort': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateBridgePort,
                    request_deserializer=l2__xpu__infra__mgr__pb2.CreateBridgePortRequest.FromString,
                    response_serializer=l2__xpu__infra__mgr__pb2.BridgePort.SerializeToString,
            ),
            'ListBridgePorts': grpc.unary_unary_rpc_method_handler(
                    servicer.ListBridgePorts,
                    request_deserializer=l2__xpu__infra__mgr__pb2.ListBridgePortsRequest.FromString,
                    response_serializer=l2__xpu__infra__mgr__pb2.ListBridgePortsResponse.SerializeToString,
            ),
            'GetBridgePort': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBridgePort,
                    request_deserializer=l2__xpu__infra__mgr__pb2.GetBridgePortRequest.FromString,
                    response_serializer=l2__xpu__infra__mgr__pb2.BridgePort.SerializeToString,
            ),
            'DeleteBridgePort': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteBridgePort,
                    request_deserializer=l2__xpu__infra__mgr__pb2.DeleteBridgePortRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateBridgePort': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateBridgePort,
                    request_deserializer=l2__xpu__infra__mgr__pb2.UpdateBridgePortRequest.FromString,
                    response_serializer=l2__xpu__infra__mgr__pb2.BridgePort.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'opi_api.network.evpn_gw.v1alpha1.BridgePortService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class BridgePortService(object):
    """Management of BridgePort resources
    """

    @staticmethod
    def CreateBridgePort(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.network.evpn_gw.v1alpha1.BridgePortService/CreateBridgePort',
            l2__xpu__infra__mgr__pb2.CreateBridgePortRequest.SerializeToString,
            l2__xpu__infra__mgr__pb2.BridgePort.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListBridgePorts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.network.evpn_gw.v1alpha1.BridgePortService/ListBridgePorts',
            l2__xpu__infra__mgr__pb2.ListBridgePortsRequest.SerializeToString,
            l2__xpu__infra__mgr__pb2.ListBridgePortsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBridgePort(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.network.evpn_gw.v1alpha1.BridgePortService/GetBridgePort',
            l2__xpu__infra__mgr__pb2.GetBridgePortRequest.SerializeToString,
            l2__xpu__infra__mgr__pb2.BridgePort.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteBridgePort(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.network.evpn_gw.v1alpha1.BridgePortService/DeleteBridgePort',
            l2__xpu__infra__mgr__pb2.DeleteBridgePortRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateBridgePort(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.network.evpn_gw.v1alpha1.BridgePortService/UpdateBridgePort',
            l2__xpu__infra__mgr__pb2.UpdateBridgePortRequest.SerializeToString,
            l2__xpu__infra__mgr__pb2.BridgePort.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tunnel.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import networktypes_pb2 as networktypes__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0ctunnel.proto\x12\x1eopi_api.network.cloud.v1alpha1\x1a\x12networktypes.proto\x1a\x19google/api/resource.proto\"\xdf\x01\n\x06Tunnel\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12>\n\x04spec\x18\x02 \x01(\x0b\x32*.opi_api.network.cloud.v1alpha1.TunnelSpecR\x04spec\x12\x44\n\x06status\x18\x03 \x01(\x0b\x32,.opi_api.network.cloud.v1alpha1.TunnelStatusR\x06status:;\xea\x41\x38\n%opi_api.network.cloud.v1alpha1/tunnel\x12\x0ftunnel/{tunnel}\"\xe7\x04\n\nTunnelSpec\x12 \n\x0cvpc_name_ref\x18\x01 \x01(\tR\nvpcNameRef\x12K\n\x08local_ip\x18\x02 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.IPAddressR\x07localIp\x12M\n\tremote_ip\x18\x03 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.IPAddressR\x08remoteIp\x12>\n\x04type\x18\x04 \x01(\x0e\x32*.opi_api.network.cloud.v1alpha1.TunnelTypeR\x04type\x12\x42\n\x05\x65ncap\x18\x05 \x01(\x0b\x32,.opi_api.network.opinetcommon.v1alpha1.EncapR\x05\x65ncap\x12*\n\x10nexthop_name_ref\x18\x06 \x01(\tH\x00R\x0enexthopNameRef\x12\x35\n\x16nexthop_group_name_ref\x18\x07 \x01(\tH\x00R\x13nexthopGroupNameRef\x12(\n\x0ftunnel_name_ref\x18\x08 \x01(\tH\x00R\rtunnelNameRef\x12Q\n\rdrop_next_hop\x18\t \x01(\x0b\x32+.opi_api.network.cloud.v1alpha1.DropNexthopH\x00R\x0b\x64ropNextHop\x12\x1f\n\x0bmac_address\x18\n \x01(\x0cR\nmacAddress\x12\x10\n\x03tos\x18\x0b \x01(\x05R\x03tosB\x04\n\x02nh\"\r\n\x0b\x44ropNexthop\"{\n\x0cTunnelStatus\x12L\n\thw_handle\x18\x01 \x01(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.HwHandleR\x08hwHandle\x12\x1d\n\nvnic_count\x18\x02 \x01(\x05R\tvnicCount*\xb7\x01\n\nTunnelType\x12\x1b\n\x17TUNNEL_TYPE_UNSPECIFIED\x10\x00\x12\x13\n\x0fTUNNEL_TYPE_IGW\x10\x01\x12\x18\n\x14TUNNEL_TYPE_WORKLOAD\x10\x02\x12\x18\n\x14TUNNEL_TYPE_INTER_DC\x10\x03\x12\x17\n\x13TUNNEL_TYPE_SERVICE\x10\x04\x12\x13\n\x0fTUNNEL_TYPE_VNF\x10\x05\x12\x15\n\x11TUNNEL_TYPE_IPSEC\x10\x06\x42l\n\x1eopi_api.network.cloud.v1alpha1B\x0bTunnelProtoP\x01Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tunnel_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036opi_api.network.cloud.v1alpha1B\013TunnelProtoP\001Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/go'
  _globals['_TUNNEL']._options = None
  _globals['_TUNNEL']._serialized_options = b'\352A8\n%opi_api.network.cloud.v1alpha1/tunnel\022\017tunnel/{tunnel}'
  _globals['_TUNNELTYPE']._serialized_start=1080
  _globals['_TUNNELTYPE']._serialized_end=1263
  _globals['_TUNNEL']._serialized_start=96
  _globals['_TUNNEL']._serialized_end=319
  _globals['_TUNNELSPEC']._serialized_start=322
  _globals['_TUNNELSPEC']._serialized_end=937
  _globals['_DROPNEXTHOP']._serialized_start=939
  _globals['_DROPNEXTHOP']._serialized_end=952
  _globals['_TUNNELSTATUS']._serialized_start=954
  _globals['_TUNNELSTATUS']._serialized_end=1077
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: route.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import networktypes_pb2 as networktypes__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0broute.proto\x12\x1eopi_api.network.cloud.v1alpha1\x1a\x12networktypes.proto\x1a\x19google/api/resource.proto\"\xf8\x01\n\nRouteTable\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x42\n\x04spec\x18\x02 \x01(\x0b\x32..opi_api.network.cloud.v1alpha1.RouteTableSpecR\x04spec\x12H\n\x06status\x18\x03 \x01(\x0b\x32\x30.opi_api.network.cloud.v1alpha1.RouteTableStatusR\x06status:H\xea\x41\x45\n)opi_api.network.cloud.v1alpha1/routetable\x12\x18routetables/{routetable}\"\xb9\x01\n\x0eRouteTableSpec\x12;\n\x02\x61\x66\x18\x01 \x01(\x0e\x32+.opi_api.network.opinetcommon.v1alpha1.IpAfR\x02\x61\x66\x12\'\n\x0fpriority_enable\x18\x02 \x01(\x08R\x0epriorityEnable\x12\x41\n\x06routes\x18\x03 \x03(\x0b\x32).opi_api.network.cloud.v1alpha1.RouteInfoR\x06routes\"h\n\tRouteInfo\x12\x19\n\x08route_id\x18\x01 \x01(\tR\x07routeId\x12@\n\x05\x61ttrs\x18\x02 \x01(\x0b\x32*.opi_api.network.cloud.v1alpha1.RouteAttrsR\x05\x61ttrs\"\xbb\x02\n\x10RouteTableStatus\x12\x1b\n\tvpc_count\x18\x01 \x01(\x05R\x08vpcCount\x12!\n\x0csubnet_count\x18\x02 \x01(\x05R\x0bsubnetCount\x12\x1d\n\nvnic_count\x18\x03 \x01(\x05R\tvnicCount\x12\x17\n\x07pool_id\x18\x04 \x01(\x05R\x06poolId\x12\x15\n\x06hw_idx\x18\x05 \x01(\x05R\x05hwIdx\x12\x37\n\x18route_table_base_address\x18\x06 \x01(\x04R\x15routeTableBaseAddress\x12\'\n\x10hw_lpm_block_idx\x18\x07 \x01(\x05R\rhwLpmBlockIdx\x12\x36\n\x18hw_lpm_rewrite_block_idx\x18\x08 \x01(\x05R\x14hwLpmRewriteBlockIdx\"\xf3\x05\n\nRouteAttrs\x12G\n\x06prefix\x18\x01 \x01(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.IPPrefixR\x06prefix\x12K\n\x0broute_class\x18\x02 \x01(\x0e\x32*.opi_api.network.cloud.v1alpha1.RouteClassR\nrouteClass\x12%\n\x0e\x63lass_priority\x18\x03 \x01(\x05R\rclassPriority\x12\x1a\n\x08priority\x18\x04 \x01(\x05R\x08priority\x12\x63\n\x12overlay_nh_ip_info\x18\x05 \x01(\x0b\x32\x34.opi_api.network.cloud.v1alpha1.OverlayNextHopIPInfoH\x00R\x0foverlayNhIpInfo\x12*\n\x10nexthop_name_ref\x18\x06 \x01(\tH\x00R\x0enexthopNameRef\x12+\n\x11nh_group_name_ref\x18\x07 \x01(\tH\x00R\x0enhGroupNameRef\x12O\n\x0bvpc_nh_info\x18\x08 \x01(\x0b\x32-.opi_api.network.cloud.v1alpha1.VPCPeerNhInfoH\x00R\tvpcNhInfo\x12(\n\x0ftunnel_name_ref\x18\t \x01(\tH\x00R\rtunnelNameRef\x12\x31\n\x14route_table_name_ref\x18\n \x01(\tH\x00R\x11routeTableNameRef\x12#\n\x0c\x65val_mapping\x18\x0b \x01(\x08H\x00R\x0b\x65valMapping\x12\x10\n\x03tos\x18\x0c \x01(\x05R\x03tos\x12\x42\n\x05\x65ncap\x18\r \x01(\x0b\x32,.opi_api.network.opinetcommon.v1alpha1.EncapR\x05\x65ncap\x12\x1f\n\x0boverlay_mac\x18\x0e \x01(\x0cR\noverlayMacB\x04\n\x02nh\"b\n\rVPCPeerNhInfo\x12 \n\x0cvpc_name_ref\x18\x01 \x01(\tR\nvpcNameRef\x12/\n\x14route_table_name_ref\x18\x02 \x01(\tR\x11routeTableNameRef\"\xaa\x01\n\x14OverlayNextHopIPInfo\x12O\n\nnexthop_ip\x18\x01 \x03(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.IPAddressR\tnexthopIp\x12\x1f\n\x0bnexthop_mac\x18\x02 \x03(\x0cR\nnexthopMac\x12 \n\x0cvpc_name_ref\x18\x03 \x01(\tR\nvpcNameRef\"U\n\x07RouteId\x12\x19\n\x08route_id\x18\x01 \x01(\tR\x07routeId\x12/\n\x14route_table_name_ref\x18\x02 \x01(\tR\x11routeTableNameRef\"\xda\x01\n\x05Route\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12=\n\x04spec\x18\x02 \x01(\x0b\x32).opi_api.network.cloud.v1alpha1.RouteSpecR\x04spec\x12\x43\n\x06status\x18\x03 \x01(\x0b\x32+.opi_api.network.cloud.v1alpha1.RouteStatusR\x06status:9\xea\x41\x36\n$opi_api.network.cloud.v1alpha1/route\x12\x0eroutes/{route}\"~\n\tRouteSpec\x12/\n\x14route_table_name_ref\x18\x01 \x01(\tR\x11routeTableNameRef\x12@\n\x05\x61ttrs\x18\x02 \x01(\x0b\x32*.opi_api.network.cloud.v1alpha1.RouteAttrsR\x05\x61ttrs\"\r\n\x0bRouteStatus*q\n\nRouteClass\x12\x1b\n\x17ROUTE_CLASS_UNSPECIFIED\x10\x00\x12\x18\n\x14ROUTE_CLASS_INTERNET\x10\x01\x12\x17\n\x13ROUTE_CLASS_SERVICE\x10\x02\x12\x13\n\x0fROUTE_CLASS_VPC\x10\x03\x42k\n\x1eopi_api.network.cloud.v1alpha1B\nRouteProtoP\x01Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'route_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\036opi_api.network.cloud.v1alpha1B\nRouteProtoP\001Z;github.com/opiproject/opi-api/network/cloud/v1alpha1/gen/go'
  _globals['_ROUTETABLE']._options = None
  _globals['_ROUTETABLE']._serialized_options = b'\352AE\n)opi_api.network.cloud.v1alpha1/routetable\022\030routetables/{routetable}'
  _globals['_ROUTE']._options = None
  _globals['_ROUTE']._serialized_options = b'\352A6\n$opi_api.network.cloud.v1alpha1/route\022\016routes/{route}'
  _globals['_ROUTECLASS']._serialized_start=2439
  _globals['_ROUTECLASS']._serialized_end=2552
  _globals['_ROUTETABLE']._serialized_start=95
  _globals['_ROUTETABLE']._serialized_end=343
  _globals['_ROUTETABLESPEC']._serialized_start=346
  _globals['_ROUTETABLESPEC']._serialized_end=531
  _globals['_ROUTEINFO']._serialized_start=533
  _globals['_ROUTEINFO']._serialized_end=637
  _globals['_ROUTETABLESTATUS']._serialized_start=640
  _globals['_ROUTETABLESTATUS']._serialized_end=955
  _globals['_ROUTEATTRS']._serialized_start=958
  _globals['_ROUTEATTRS']._serialized_end=1713
  _globals['_VPCPEERNHINFO']._serialized_start=1715
  _globals['_VPCPEERNHINFO']._serialized_end=1813
  _globals['_OVERLAYNEXTHOPIPINFO']._serialized_start=1816
  _globals['_OVERLAYNEXTHOPIPINFO']._serialized_end=1986
  _globals['_ROUTEID']._serialized_start=1988
  _globals['_ROUTEID']._serialized_end=2073
  _globals['_ROUTE']._serialized_start=2076
  _globals['_ROUTE']._serialized_end=2294
  _globals['_ROUTESPEC']._serialized_start=2296
  _globals['_ROUTESPEC']._serialized_end=2422
  _globals['_ROUTESTATUS']._serialized_start=2424
  _globals['_ROUTESTATUS']._serialized_end=2437
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: networktypes.proto
# Protobuf Python Version: 4.25.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12networktypes.proto\x12%opi_api.network.opinetcommon.v1alpha1\"\x8a\x01\n\tIPAddress\x12;\n\x02\x61\x66\x18\x01 \x01(\x0e\x32+.opi_api.network.opinetcommon.v1alpha1.IpAfR\x02\x61\x66\x12\x19\n\x07v4_addr\x18\x02 \x01(\x07H\x00R\x06v4Addr\x12\x19\n\x07v6_addr\x18\x03 \x01(\x0cH\x00R\x06v6AddrB\n\n\x08v4_or_v6\"b\n\x08IPPrefix\x12\x44\n\x04\x61\x64\x64r\x18\x01 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.IPAddressR\x04\x61\x64\x64r\x12\x10\n\x03len\x18\x02 \x01(\x05R\x03len\"2\n\nIPv4Prefix\x12\x12\n\x04\x61\x64\x64r\x18\x01 \x01(\x07R\x04\x61\x64\x64r\x12\x10\n\x03len\x18\x02 \x01(\x05R\x03len\"2\n\nIPv6Prefix\x12\x12\n\x04\x61\x64\x64r\x18\x01 \x01(\x0cR\x04\x61\x64\x64r\x12\x10\n\x03len\x18\x02 \x01(\x05R\x03len\"u\n\x08\x45ncapVal\x12\x19\n\x07vlan_id\x18\x01 \x01(\x05H\x00R\x06vlanId\x12\x1b\n\x08mpls_tag\x18\x02 \x01(\x05H\x00R\x07mplsTag\x12\x14\n\x04vnid\x18\x03 \x01(\x05H\x00R\x04vnid\x12\x14\n\x04vsid\x18\x05 \x01(\x05H\x00R\x04vsidB\x05\n\x03val\"\x94\x01\n\x05\x45ncap\x12\x44\n\x04type\x18\x01 \x01(\x0e\x32\x30.opi_api.network.opinetcommon.v1alpha1.EncapTypeR\x04type\x12\x45\n\x05value\x18\x02 \x01(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.EncapValR\x05value\"C\n\tPortRange\x12\x19\n\x08port_low\x18\x01 \x01(\x05R\x07portLow\x12\x1b\n\tport_high\x18\x02 \x01(\x05R\x08portHigh\"\x93\x01\n\x07IPRange\x12\x42\n\x03low\x18\x01 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.IPAddressR\x03low\x12\x44\n\x04high\x18\x02 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.IPAddressR\x04high\"\xb9\x01\n\x0c\x41\x64\x64ressRange\x12O\n\nipv4_range\x18\x01 \x01(\x0b\x32..opi_api.network.opinetcommon.v1alpha1.IPRangeH\x00R\tipv4Range\x12O\n\nipv6_range\x18\x02 \x01(\x0b\x32..opi_api.network.opinetcommon.v1alpha1.IPRangeH\x00R\tipv6RangeB\x07\n\x05range\"\xc1\x01\n\x07IPEntry\x12I\n\x06prefix\x18\x01 \x01(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.IPPrefixH\x00R\x06prefix\x12K\n\x05range\x18\x02 \x01(\x0b\x32\x33.opi_api.network.opinetcommon.v1alpha1.AddressRangeH\x00R\x05range\x12\x12\n\x03tag\x18\x03 \x01(\x05H\x00R\x03tagB\n\n\x08ip_entry\"W\n\x06IPList\x12M\n\nip_entries\x18\x01 \x03(\x0b\x32..opi_api.network.opinetcommon.v1alpha1.IPEntryR\tipEntries\"\xd6\x05\n\x0bRuleL3Match\x12\x1d\n\tproto_num\x18\x01 \x01(\x05H\x00R\x08protoNum\x12^\n\x0fproto_wild_card\x18\x02 \x01(\x0e\x32\x34.opi_api.network.opinetcommon.v1alpha1.WildcardMatchH\x00R\rprotoWildCard\x12P\n\nsrc_prefix\x18\x03 \x01(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.IPPrefixH\x01R\tsrcPrefix\x12R\n\tsrc_range\x18\x04 \x01(\x0b\x32\x33.opi_api.network.opinetcommon.v1alpha1.AddressRangeH\x01R\x08srcRange\x12\x19\n\x07src_tag\x18\x05 \x01(\x05H\x01R\x06srcTag\x12O\n\x0bsrc_ip_list\x18\x06 \x01(\x0b\x32-.opi_api.network.opinetcommon.v1alpha1.IPListH\x01R\tsrcIpList\x12P\n\ndst_prefix\x18\x07 \x01(\x0b\x32/.opi_api.network.opinetcommon.v1alpha1.IPPrefixH\x02R\tdstPrefix\x12R\n\tdst_range\x18\x08 \x01(\x0b\x32\x33.opi_api.network.opinetcommon.v1alpha1.AddressRangeH\x02R\x08\x64stRange\x12\x19\n\x07\x64st_tag\x18\t \x01(\x05H\x02R\x06\x64stTag\x12O\n\x0b\x64st_ip_list\x18\n \x01(\x0b\x32-.opi_api.network.opinetcommon.v1alpha1.IPListH\x02R\tdstIpListB\x0c\n\nprotomatchB\n\n\x08srcmatchB\n\n\x08\x64stmatch\"\xbb\x01\n\tPortMatch\x12V\n\x0esrc_port_range\x18\x01 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.PortRangeR\x0csrcPortRange\x12V\n\x0e\x64st_port_range\x18\x02 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.PortRangeR\x0c\x64stPortRange\"\x8b\x02\n\tICMPMatch\x12\x14\n\x04type\x18\x01 \x01(\x05H\x00R\x04type\x12[\n\rtype_wildcard\x18\x02 \x01(\x0e\x32\x34.opi_api.network.opinetcommon.v1alpha1.WildcardMatchH\x00R\x0ctypeWildcard\x12\x14\n\x04\x63ode\x18\x03 \x01(\x05H\x01R\x04\x63ode\x12[\n\rcode_wildcard\x18\x04 \x01(\x0e\x32\x34.opi_api.network.opinetcommon.v1alpha1.WildcardMatchH\x01R\x0c\x63odeWildcardB\x0b\n\ttypematchB\x0b\n\tcodematch\"\xbf\x01\n\rPortListMatch\x12V\n\x0esrc_port_range\x18\x01 \x03(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.PortRangeR\x0csrcPortRange\x12V\n\x0e\x64st_port_range\x18\x02 \x03(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.PortRangeR\x0c\x64stPortRange\"i\n\rICMPMatchList\x12X\n\x0ficmp_match_list\x18\x01 \x03(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.ICMPMatchR\ricmpMatchList\"\xe7\x02\n\x0bRuleL4Match\x12H\n\x05ports\x18\x01 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.PortMatchH\x00R\x05ports\x12O\n\ttype_code\x18\x02 \x01(\x0b\x32\x30.opi_api.network.opinetcommon.v1alpha1.ICMPMatchH\x00R\x08typeCode\x12S\n\tport_list\x18\x03 \x01(\x0b\x32\x34.opi_api.network.opinetcommon.v1alpha1.PortListMatchH\x00R\x08portList\x12^\n\x0ficmp_match_list\x18\x04 \x01(\x0b\x32\x34.opi_api.network.opinetcommon.v1alpha1.ICMPMatchListH\x00R\ricmpMatchListB\x08\n\x06l4info\"\xa9\x01\n\tRuleMatch\x12M\n\x08l3_match\x18\x01 \x01(\x0b\x32\x32.opi_api.network.opinetcommon.v1alpha1.RuleL3MatchR\x07l3Match\x12M\n\x08l4_match\x18\x02 \x01(\x0b\x32\x32.opi_api.network.opinetcommon.v1alpha1.RuleL4MatchR\x07l4Match\"\x1c\n\x08HwHandle\x12\x10\n\x03idx\x18\x01 \x01(\x04R\x03idx*r\n\x12SecurityRuleAction\x12\x1d\n\x19SECURITY_RULE_ACTION_NONE\x10\x00\x12\x1e\n\x1aSECURITY_RULE_ACTION_ALLOW\x10\x01\x12\x1d\n\x19SECURITY_RULE_ACTION_DENY\x10\x02*>\n\x04IpAf\x12\x15\n\x11IP_AF_UNSPECIFIED\x10\x00\x12\x0e\n\nIP_AF_INET\x10\x01\x12\x0f\n\x0bIP_AF_INET6\x10\x02*\x87\x01\n\tEncapType\x12\x1a\n\x16\x45NCAP_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10\x45NCAP_TYPE_DOT1Q\x10\x01\x12\x1c\n\x18\x45NCAP_TYPE_MPLS_OVER_UDP\x10\x02\x12\x14\n\x10\x45NCAP_TYPE_VXLAN\x10\x03\x12\x14\n\x10\x45NCAP_TYPE_NVGRE\x10\x04*\x81\x01\n\tRouteType\x12\x1a\n\x16ROUTE_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10ROUTE_TYPE_OTHER\x10\x01\x12\x15\n\x11ROUTE_TYPE_REJECT\x10\x02\x12\x14\n\x10ROUTE_TYPE_LOCAL\x10\x03\x12\x15\n\x11ROUTE_TYPE_REMOTE\x10\x04*|\n\rRouteProtocol\x12\x1e\n\x1aROUTE_PROTOCOL_UNSPECIFIED\x10\x00\x12\x18\n\x14ROUTE_PROTOCOL_LOCAL\x10\x01\x12\x19\n\x15ROUTE_PROTOCOL_STATIC\x10\x02\x12\x16\n\x12ROUTE_PROTOCOL_BGP\x10\x03*s\n\nAdminState\x12\x1b\n\x17\x41\x44MIN_STATE_UNSPECIFIED\x10\x00\x12\x16\n\x12\x41\x44MIN_STATE_ENABLE\x10\x01\x12\x17\n\x13\x41\x44MIN_STATE_DISABLE\x10\x02\x12\x17\n\x13\x41\x44MIN_STATE_TESTING\x10\x03*V\n\tPolicyDir\x12\x1a\n\x16POLICY_DIR_UNSPECIFIED\x10\x00\x12\x16\n\x12POLICY_DIR_INGRESS\x10\x01\x12\x15\n\x11POLICY_DIR_EGRESS\x10\x02*A\n\rWildcardMatch\x12\x17\n\x13WILDCARD_MATCH_NONE\x10\x00\x12\x17\n\x12WILDCARD_MATCH_ANY\x10\x80\x02\x42\x80\x01\n%opi_api.network.opinetcommon.v1alpha1B\x11NetworkTypesProtoP\x01ZBgithub.com/opiproject/opi-api/network/opinetcommon/v1alpha1/gen/gob\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'networktypes_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n%opi_api.network.opinetcommon.v1alpha1B\021NetworkTypesProtoP\001ZBgithub.com/opiproject/opi-api/network/opinetcommon/v1alpha1/gen/go'
  _globals['_SECURITYRULEACTION']._serialized_start=3422
  _globals['_SECURITYRULEACTION']._serialized_end=3536
  _globals['_IPAF']._serialized_start=3538
  _globals['_IPAF']._serialized_end=3600
  _globals['_ENCAPTYPE']._serialized_start=3603
  _globals['_ENCAPTYPE']._serialized_end=3738
  _globals['_ROUTETYPE']._serialized_start=3741
  _globals['_ROUTETYPE']._serialized_end=3870
  _globals['_ROUTEPROTOCOL']._serialized_start=3872
  _globals['_ROUTEPROTOCOL']._serialized_end=3996
  _globals['_ADMINSTATE']._serialized_start=3998
  _globals['_ADMINSTATE']._serialized_end=4113
  _globals['_POLICYDIR']._serialized_start=4115
  _globals['_POLICYDIR']._serialized_end=4201
  _globals['_WILDCARDMATCH']._serialized_start=4203
  _globals['_WILDCARDMATCH']._serialized_end=4268
  _globals['_IPADDRESS']._serialized_start=62
  _globals['_IPADDRESS']._serialized_end=200
  _globals['_IPPREFIX']._serialized_start=202
  _globals['_IPPREFIX']._serialized_end=300
  _globals['_IPV4PREFIX']._serialized_start=302
  _globals['_IPV4PREFIX']._serialized_end=352
  _globals['_IPV6PREFIX']._serialized_start=354
  _globals['_IPV6PREFIX']._serialized_end=404
  _globals['_ENCAPVAL']._serialized_start=406
  _globals['_ENCAPVAL']._serialized_end=523
  _globals['_ENCAP']._serialized_start=526
  _globals['_ENCAP']._serialized_end=674
  _globals['_PORTRANGE']._serialized_start=676
  _globals['_PORTRANGE']._serialized_end=743
  _globals['_IPRANGE']._serialized_start=746
  _globals['_IPRANGE']._serialized_end=893
  _globals['_ADDRESSRANGE']._serialized_start=896
  _globals['_ADDRESSRANGE']._serialized_end=1081
  _globals['_IPENTRY']._serialized_start=1084
  _globals['_IPENTRY']._serialized_end=1277
  _globals['_IPLIST']._serialized_start=1279
  _globals['_IPLIST']._serialized_end=1366
  _globals['_RULEL3MATCH']._serialized_start=1369
  _globals['_RULEL3MATCH']._serialized_end=2095
  _globals['_PORTMATCH']._serialized_start=2098
  _globals['_PORTMATCH']._serialized_end=2285
  _globals['_ICMPMATCH']._serialized_start=2288
  _globals['_ICMPMATCH']._serialized_end=2555
  _globals['_PORTLISTMATCH']._serialized_start=2558
  _globals['_PORTLISTMATCH']._serialized_end=2749
  _globals['_ICMPMATCHLIST']._serialized_start=2751
  _globals['_ICMPMATCHLIST']._serialized_end=2856
  _globals['_RULEL4MATCH']._serialized_start=2859
  _globals['_RULEL4MATCH']._serialized_end=3218
  _globals['_RULEMATCH']._serialized_start=3221
  _globals['_RULEMATCH']._serialized_end=3390
  _globals['_HWHANDLE']._serialized_start=3392
  _globals['_HWHANDLE']._serialized_end=3420
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
import middleend_qos_volume_pb2 as middleend__qos__volume__pb2


class MiddleendQosVolumeServiceStub(object):
    """Middle End (Storage Services) APIs. For example, encryption, compression, raid, QoS, multipath, ...
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateQosVolume = channel.unary_unary(
                '/opi_api.storage.v1.MiddleendQosVolumeService/CreateQosVolume',
                request_serializer=middleend__qos__volume__pb2.CreateQosVolumeRequest.SerializeToString,
                response_deserializer=middleend__qos__volume__pb2.QosVolume.FromString,
                )
        self.DeleteQosVolume = channel.unary_unary(
                '/opi_api.storage.v1.MiddleendQosVolumeService/DeleteQosVolume',
                request_serializer=middleend__qos__volume__pb2.DeleteQosVolumeRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.UpdateQosVolume = channel.unary_unary(
                '/opi_api.storage.v1.MiddleendQosVolumeService/UpdateQosVolume',
                request_serializer=middleend__qos__volume__pb2.UpdateQosVolumeRequest.SerializeToString,
                response_deserializer=middleend__qos__volume__pb2.QosVolume.FromString,
                )
        self.ListQosVolumes = channel.unary_unary(
                '/opi_api.storage.v1.MiddleendQosVolumeService/ListQosVolumes',
                request_serializer=middleend__qos__volume__pb2.ListQosVolumesRequest.SerializeToString,
                response_deserializer=middleend__qos__volume__pb2.ListQosVolumesResponse.FromString,
                )
        self.GetQosVolume = channel.unary_unary(
                '/opi_api.storage.v1.MiddleendQosVolumeService/GetQosVolume',
                request_serializer=middleend__qos__volume__pb2.GetQosVolumeRequest.SerializeToString,
                response_deserializer=middleend__qos__volume__pb2.QosVolume.FromString,
                )
        self.StatsQosVolume = channel.unary_unary(
                '/opi_api.storage.v1.MiddleendQosVolumeService/StatsQosVolume',
                request_serializer=middleend__qos__volume__pb2.StatsQosVolumeRequest.SerializeToString,
                response_deserializer=middleend__qos__volume__pb2.StatsQosVolumeResponse.FromString,
                )


class MiddleendQosVolumeServiceServicer(object):
    """Middle End (Storage Services) APIs. For example, encryption, compression, raid, QoS, multipath, ...
    """

    def CreateQosVolume(self, request, context):
        """Create an Qos Volume
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteQosVolume(self, request, context):
        """Delete an Qos Volume
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateQosVolume(self, request, context):
        """Update an Qos Volume
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListQosVolumes(self, request, context):
        """List Qos Volumes
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetQosVolume(self, request, context):
        """Get an Qos Volume
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StatsQosVolume(self, request, context):
        """Get an Qos Volume statistics
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MiddleendQosVolumeServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateQosVolume': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateQosVolume,
                    request_deserializer=middleend__qos__volume__pb2.CreateQosVolumeRequest.FromString,
                    response_serializer=middleend__qos__volume__pb2.QosVolume.SerializeToString,
            ),
            'DeleteQosVolume': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteQosVolume,
                    request_deserializer=middleend__qos__volume__pb2.DeleteQosVolumeRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'UpdateQosVolume': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateQosVolume,
                    request_deserializer=middleend__qos__volume__pb2.UpdateQosVolumeRequest.FromString,
                    response_serializer=middleend__qos__volume__pb2.QosVolume.SerializeToString,
            ),
            'ListQosVolumes': grpc.unary_unary_rpc_method_handler(
                    servicer.ListQosVolumes,
                    request_deserializer=middleend__qos__volume__pb2.ListQosVolumesRequest.FromString,
                    response_serializer=middleend__qos__volume__pb2.ListQosVolumesResponse.SerializeToString,
            ),
            'GetQosVolume': grpc.unary_unary_rpc_method_handler(
                    servicer.GetQosVolume,
                    request_deserializer=middleend__qos__volume__pb2.GetQosVolumeRequest.FromString,
                    response_serializer=middleend__qos__volume__pb2.QosVolume.SerializeToString,
            ),
            'StatsQosVolume': grpc.unary_unary_rpc_method_handler(
                    servicer.StatsQosVolume,
                    request_deserializer=middleend__qos__volume__pb2.StatsQosVolumeRequest.FromString,
                    response_serializer=middleend__qos__volume__pb2.StatsQosVolumeResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'opi_api.storage.v1.MiddleendQosVolumeService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MiddleendQosVolumeService(object):
    """Middle End (Storage Services) APIs. For example, encryption, compression, raid, QoS, multipath, ...
    """

    @staticmethod
    def CreateQosVolume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.MiddleendQosVolumeService/CreateQosVolume',
            middleend__qos__volume__pb2.CreateQosVolumeRequest.SerializeToString,
            middleend__qos__volume__pb2.QosVolume.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteQosVolume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.MiddleendQosVolumeService/DeleteQosVolume',
            middleend__qos__volume__pb2.DeleteQosVolumeRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateQosVolume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.MiddleendQosVolumeService/UpdateQosVolume',
            middleend__qos__volume__pb2.UpdateQosVolumeRequest.SerializeToString,
            middleend__qos__volume__pb2.QosVolume.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListQosVolumes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.MiddleendQosVolumeService/ListQosVolumes',
            middleend__qos__volume__pb2.ListQosVolumesRequest.SerializeToString,
            middleend__qos__volume__pb2.ListQosVolumesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetQosVolume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.MiddleendQosVolumeService/GetQosVolume',
            middleend__qos__volume__pb2.GetQosVolumeRequest.SerializeToString,
            middleend__qos__volume__pb2.QosVolume.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StatsQosVolume(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/opi_api.storage.v1.MiddleendQosVolumeService/StatsQosVolume',
            middleend__qos__volume__pb2.StatsQosVolumeRequest.SerializeToString,
            middleend__qos__volume__pb2.StatsQosVolumeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
